@@ -4,7 +4,7 @@
 #include "colourvalues/scale/scale.hpp"
 #include "colourvalues/utils/utils.hpp"
 #include "colourvalues/palette_utils/palette_utils.hpp"
-#include "colourvalues/convert_colours/convert_colours.hpp"
+#include "colourvalues/convert/convert_colours.hpp"
 
 //[[Rcpp::depends(BH)]]
 #include <boost/math/interpolators/cubic_b_spline.hpp>
