@@ -33,3 +33,13 @@ test_that("first 4 columns of palette matrix used",{
 
 
 })
+
+## issue 58
+test_that("palettes returned either RGB or hex",{
+  pal <- get_palette("viridis")
+  expect_true( is.matrix( pal ))
+  expect_true( is.numeric( pal ))
+  pal <- get_palette("viridis", FALSE)
+  expect_false( is.matrix( pal ))
+  expect_true( is.character( pal ))
+})
